![booklab_logo](../pictures/booklab_logo.png){ width="55" align=left }
<small markdown>**BookLab System**<br>
*(c) 2023 RENware Software Systems*
</small><br><br>



# Catalogul manualelor de configurare si administrare


* [Fisierul de configurare a cartii](880.30-TMPL_usage.md)
* ...


